@@ -39,6 +39,7 @@ MAX_COLUMN_WIDTH = {
     'command': 16
 }
 
+
 def action(msg, **kwargs):
     click.secho(msg.format(**kwargs), nl=False, bold=True)
 
@@ -46,9 +47,11 @@ def action(msg, **kwargs):
 def ok(**kwargs):
     click.secho(' OK', fg='green', bold=True, **kwargs)
 
+
 def error(msg, **kwargs):
     click.secho(' {}'.format(msg), fg='red', bold=True, **kwargs)
 
+
 def format_time(ts):
     if ts == 0:
         return ''
@@ -58,15 +61,16 @@ def format_time(ts):
     except:
         return ts
     diff = now - dt
-    s =  diff.total_seconds()
+    s = diff.total_seconds()
     if s > 3600:
-        t = '{:.0f}h'.format(s/3600)
+        t = '{:.0f}h'.format(s / 3600)
     elif s > 60:
-        t = '{:.0f}m'.format(s/60)
+        t = '{:.0f}m'.format(s / 60)
     else:
         t = '{:.0f}s'.format(s)
     return '{} ago'.format(t)
 
+
 def format(col, val):
     if val is None:
         val = ''
@@ -78,6 +82,7 @@ def format(col, val):
         val = str(val)
     return val
 
+
 def print_table(cols, rows):
     colwidths = {}
 
@@ -90,7 +95,8 @@ def print_table(cols, rows):
             colwidths[col] = min(max(colwidths[col], len(format(col, val))), MAX_COLUMN_WIDTH.get(col, 1000))
 
     for col in cols:
-        click.secho(('{:' + str(colwidths[col]) + '}').format(TITLES.get(col, col.title().replace('_', ' '))), nl=False, fg='black', bg='white')
+        click.secho(('{:' + str(colwidths[col]) + '}').format(TITLES.get(col, col.title().replace('_', ' '))),
+                    nl=False, fg='black', bg='white')
         click.secho(' ', nl=False, fg='black', bg='white')
     click.echo('')
 
@@ -111,7 +117,7 @@ def print_table(cols, rows):
             val = format(col, val)
 
             if len(val) > MAX_COLUMN_WIDTH.get(col, 1000):
-                val = val[:MAX_COLUMN_WIDTH.get(col, 1000)-2] + '..'
+                val = val[:MAX_COLUMN_WIDTH.get(col, 1000) - 2] + '..'
             click.secho(('{:' + align + str(colwidths[col]) + '}').format(val), nl=False, **style)
             click.echo(' ', nl=False)
         click.echo('')
\ No newline at end of file
