@@ -7,7 +7,7 @@ from pequod_cli.controller.cli import _state, controller
 from pequod_cli.manager.cli import manager
 from pequod_cli.registry.cli import registry
 from pequod_cli.replicator.cli import replicator
-from pequod_cli.service import CORE_PORTS
+from pequod_cli.service import CORE_DOMAINS
 from pequod_cli.utils import AliasedGroup
 import click
 import logging
@@ -58,10 +58,12 @@ def cli(ctx, config_file, cluster, verbose):
 Please use the "login" command or edit the configuration file {} manually.'''.format(cluster, fn))
         endpoints = data[cluster]['endpoints']
         credentials = data[cluster]['credentials']
+        cacert = data[cluster].get('cacert')
     else:
         endpoints = {}
         credentials = None
-    ctx.obj = Context(fn, cluster, endpoints, credentials)
+        cacert = None
+    ctx.obj = Context(fn, cluster, endpoints, credentials, cacert)
     if not ctx.invoked_subcommand:
         _state(ctx.obj)
 
@@ -78,22 +80,26 @@ class Endpoints(click.ParamType):
         parts = [v.strip() for v in value.split(',')]
 
         if parts[0].startswith('http'):
-            for k, port in CORE_PORTS.items():
-                endpoints[k] = [h.format(service=k) for h in parts]
+            # pequod login -d http(s)://{domain}.pequod.example.org
+            for service, domain in CORE_DOMAINS.items():
+                endpoints[service] = [h.format(service=service, domain=domain) for h in parts]
         else:
-            hosts = parts
-            for k, port in CORE_PORTS.items():
-                    endpoints[k] = ['http://{}:{}/'.format(h, port) for h in hosts]
+            # pequod login -d pequod.example.org
+            # pequod login -d .pequod.example.org
+            domains = parts
+            for service, subdomain in CORE_DOMAINS.items():
+                endpoints[service] = ['https://{}.{}/'.format(subdomain, domain.strip('.')) for domain in domains]
         return endpoints
 
 
 @cli.command()
-@click.option('-e', '--endpoints', help='Endpoints',
-              prompt='Service endpoints (list of IPs/URLs or complete JSON dict)', metavar='CONFIG', type=Endpoints())
+@click.option('-d', '--domain', 'endpoints', help='Cluster domain address',
+              prompt='Cluster domain (e.g. "pequod.example.org")', metavar='DOMAIN', type=Endpoints())
 @click.option('-u', '--username', help='Username', prompt='Username', metavar='USER')
 @click.option('-p', '--password', help='Password', prompt=True, hide_input=True, metavar='PASSWD')
+@click.option('--cacert', help='CA certificate to verify peer against (SSL)', metavar='FILE')
 @click.pass_context
-def login(click_context, endpoints, username, password):
+def login(click_context, endpoints, username, password, cacert):
     """
     Login to a cluster and store credentials
     """
@@ -101,7 +107,7 @@ def login(click_context, endpoints, username, password):
 
     credentials = {'username': username, 'password': password}
     ctx = click_context.obj
-    ctx = Context(ctx.config_file, ctx.cluster, endpoints, credentials)
+    ctx = Context(ctx.config_file, ctx.cluster, endpoints, credentials, cacert)
 
     has_errors = False
     for svc in ctx.all_core_services:
@@ -116,7 +122,7 @@ def login(click_context, endpoints, username, password):
 
     if has_errors:
         click.secho('''WARNING: At least one core service could not be reached.
-Check your username/password and endpoint IPs.''', bold=True, fg='yellow')
+Check your username/password and cluster domain address.''', bold=True, fg='yellow')
 
     try:
         with open(ctx.config_file) as fd:
@@ -128,7 +134,7 @@ Check your username/password and endpoint IPs.''', bold=True, fg='yellow')
         cluster=ctx.cluster, fn=ctx.config_file), abort=True)
 
     action('Storing configuration for cluster {cluster} at {fn}..', cluster=ctx.cluster, fn=ctx.config_file)
-    data[ctx.cluster] = {'endpoints': endpoints, 'credentials': credentials}
+    data[ctx.cluster] = {'endpoints': endpoints, 'credentials': credentials, 'cacert': cacert}
 
     with open(ctx.config_file, 'w') as fd:
         yaml.safe_dump(data, fd)
